import { Component, EventEmitter, OnInit, Output } from '@angular/core';
import { FormBuilder, FormGroup } from '@angular/forms';
import { debounceTime, distinctUntilChanged } from 'rxjs/operators';

/**
 * Searchbar that outputs the search values on input change
 */
@Component({
  selector: 'app-search-bar',
  templateUrl: './search-bar.component.html',
  styleUrls: ['./search-bar.component.scss']
})
export class SearchBarComponent implements OnInit {
  /**
   * FormGroup
   */
  form: FormGroup;
  /**
   * Event emitter triggering whenever the input value changes
   */
  @Output() searchValue = new EventEmitter<string>();
  constructor(private formBuilder: FormBuilder) { }

  /**
   * Builds form and subscribes on input value change
   */
  ngOnInit() {
    this.form = this.formBuilder.group({
      searchTerm: ['']
    });

    this.form.get('searchTerm').valueChanges
      .pipe(
        debounceTime(400),
        distinctUntilChanged()
      ).subscribe(() => this.searchValue.next(this.form.get('searchTerm').value));
  }

}
