import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable, of, Subject } from 'rxjs';
import { catchError, tap } from 'rxjs/operators';

@Injectable({
  providedIn: 'root'
})
export class AuthService {

  /**
   * backend endpoint
   */
  private readonly endpoint = '/api/session';

  /**
   * Subject handling token changes
   */
  hasToken: Subject<boolean> = new Subject<boolean>();

  /**
   * Flag determining if user is logged in
   */
  loggedIn = false;

  constructor(
    private http: HttpClient,
  ) {
    this.checkValidity();
  }

  /**
   * Checks the validity of present cookie
   */
  checkValidity() {
    return this.http.get('api/user').subscribe(() => {
      this.loggedIn = true;

      this.hasToken.next(true);
    });
  }

  /**
   * Login
   * @param token
   */
  validateToken(token: string): Observable<any> {
    if (token && token !== '') {
      return this.http.put(this.endpoint, { sessionId: token }).pipe(
        tap(() => {
          this.hasToken.next(true);
          this.loggedIn = true;
        })
      );
    }
    return of();
  }

  /**
   * Logout
   */
  logout(): Observable<any> {
    return this.http.get(`api/user/logout`).pipe(
      tap(() => {
        this.loggedIn = false;
        this.hasToken.next(false);
      })
    );
  }
}
