import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable, of } from 'rxjs';
import { Event } from '../models/Event';
import { EventsResultsWrapper } from '../models/EventsResultsWrapper';
import { GetQuery } from '../models/get-query';
import { ResultsWrapper } from '../models/ResultsWrapper';
import { AuthService } from './auth.service';
import { HttpRequestCachingService } from './http-request-caching.service';

@Injectable({
  providedIn: 'root'
})
export class EventsService {

  private readonly endpoint = '/api/events';

  constructor(
    private httpClient: HttpClient,
    private httpRequestCachingService: HttpRequestCachingService,
    private authService: AuthService
  ) { }

  /**
   * Retrieve event
   * @param query
   */
  getEvents(query: GetQuery): Observable<EventsResultsWrapper> {
    return this.httpClient.get<EventsResultsWrapper>(`${this.endpoint}${query.buildParameters()}`);
  }

  /**
   * Change event state
   * @param event
   * @param attendance
   */
  attendEvent(event: Event, attendance: Event.Attendance) {
    if (event.id && event.id !== '') {
      const request = this.httpClient.put(`${this.endpoint}/${event.id}/attend`, { attendance });
      if (this.authService.loggedIn) {
        return request;
      }
      this.httpRequestCachingService.addToCache(request, event);
    }
    return of({});
  }

  /**
   * Retrieve specific event
   * @param uuid
   */
  getEvent(uuid: string): Observable<Event> {
    return this.httpClient.get<Event>(`${this.endpoint}/${uuid}`);
  }
}
