import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { of } from 'rxjs';
import { catchError } from 'rxjs/operators';
import { AuthService } from '../common/services/auth.service';

/**
 * Component handling login/token validation
 */
@Component({
  selector: 'app-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.scss']
})
export class LoginComponent implements OnInit {
  /**
   * FormGroup
   */
  form: FormGroup;
  /**
   * Flag determines if login error message should be shown
   */
  showError = false;

  constructor(
    private authService: AuthService,
    private formBuilder: FormBuilder,
    private router: Router,
  ) { }

  /**
   * Builds form
   */
  ngOnInit() {
    this.form = this.formBuilder.group({
      token: [null, Validators.required]
    });
  }

  /**
   * Validates given token
   */
  validate() {
    this.showError = false;

    let token: string = this.form.get('token').value;
    token = token.replace('-', '');

    this.authService.validateToken(token).pipe(
      catchError(() => {
        this.showError = true;
        return of();
      })
    ).subscribe(() => {
      this.router.navigate(['']);
    });
  }

}
