import { Component, Input, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { Observable } from 'rxjs';
import { Event } from 'src/app/common/models/Event';
import { AuthService } from 'src/app/common/services/auth.service';
import { EventsService } from 'src/app/common/services/events.service';
import { Utility } from 'src/app/common/utility/Utility';

@Component({
  selector: 'app-event-details',
  templateUrl: './event-details.component.html',
  styleUrls: ['./event-details.component.scss']
})
export class EventDetailsComponent implements OnInit {
  /**
   * All events
   */
  event: Event = {};
  /**
   * Flag determines if login button should be shown
   */
  hideLogin = false;

  constructor(
    private activatedRoute: ActivatedRoute,
    private eventService: EventsService,
    private authService: AuthService,
  ) { }

  /**
   * Retrieves event out of activated route
   */
  ngOnInit() {
    if (this.activatedRoute.snapshot.data.event) {
      this.event = this.activatedRoute.snapshot.data.event;
    }
    this.hideLogin = this.authService.loggedIn;
  }

  /**
   * Change the personal event state
   * @param type
   */
  eventInteraction(type: Event.Attendance) {
    this.eventService.attendEvent(this.event, type).subscribe(() => {
      this.fetchEvent$().subscribe((event) => {
        this.event = event;
      });
    });
  }

  /**
   * Fetch event from backend
   */
  fetchEvent$(): Observable<Event> {
    return this.eventService.getEvent(this.event.id);
  }

}
